@@ -1,9 +1,8 @@
 ## File Name: logLik_tam.R
-## File Version: 9.04
+## File Version: 9.05
 
 
-###############################################################
-# log-likelihood function tam.mml
+#-- log-likelihood function tam.mml
 logLik.tam <- function (object, ...)
 {
     # extract log-likelihood
@@ -15,8 +14,9 @@ logLik.tam <- function (object, ...)
     class(out) <- "logLik"
     return(out)
 }
-logLik.tam.mml <- logLik.tam
-################################################################
 
-logLik.tamaan <- logLik.tam.mml.3pl <- logLik.tam
+logLik.tam.mml <- logLik.tam
+logLik.tamaan <- logLik.tam
+logLik.tam.mml.3pl <- logLik.tam
 logLik.tam.latreg <- logLik.tam
+logLik.tam.np <- logLik.tam
